---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Short example reproducing the problem, see http://sscce.org/ for general guidelines.

**Expected behavior**
A clear and concise description of what you expected to happen.

**Current Behavior**
What happens instead of the expected behavior.

**Context (Environment)**
 - What are the OS, Python and FreeTDS versions?
 - please include the output of the following command:
    `/<path to your python>/python -c "import pymssql; print(pymssql.version_info())"`

**Additional context**
Add any other context about the problem here.
